#!/bin/sh

. /etc/rc.conf
. /etc/rc.d/functions

# Screen blanks after 15 minutes idle time.
/usr/bin/setterm -blank 15

# If there's no /etc/HOSTNAME, fall back on this default:
if [ ! -z $HOSTNAME ]; then
  echo "$HOSTNAME" > /etc/HOSTNAME
fi

# Set the hostname.
/bin/hostname $HOSTNAME &> /dev/null

# Start daemons
for daemon in "${DAEMONS[@]}"; do
	if [[ `echo $daemon | grep -v pcmcia | grep '^[^\!]' | wc -l` -eq 1 ]]; then
		/etc/rc.d/$daemon start
	fi
done


# Remove stale locks and junk files (must be done after mount -a!)
/bin/rm -f /var/lock/* /var/spool/uucp/LCK..* /tmp/.X*lock /tmp/core /core 1> /dev/null 2> /dev/null

# Remove stale hunt sockets so the game can start.
if [ -r /tmp/hunt -o -r /tmp/hunt.stats ]; then
  echo "Usuwanie starych plikw z /tmp."
  /bin/rm -f /tmp/hunt*
fi

# Ensure basic filesystem permissions sanity.
chmod 755 / 2> /dev/null
chmod 1777 /tmp /var/tmp

# Start the local setup procedure.
if [ -x /etc/rc.d/rc.local ]; then
  . /etc/rc.d/rc.local
fi

# All done.

